import axios from 'axios';

const login = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_SSO_AUTHENTICATION_API}/login`, data, Object.keys(headers).length > 0 && { headers });

        let userDetails = response.data;
        headers['x-access-token'] = userDetails.token;
        const userRoles = await axios.get(`${process.env.REACT_APP_ROLES_API}/user-roles/${userDetails.id}`, Object.keys(headers).length > 0 && { headers });
        const information = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${userDetails.id}`, Object.keys(headers).length > 0 && { headers });

        userDetails.roles = userRoles.data;
        userDetails.information = information.data;

        return userDetails;
    } catch (error) {
        throw error;
    }
};

const refreshToken = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_SSO_AUTHENTICATION_API}/refresh-token`, data, Object.keys(headers).length > 0 && { headers });

        let userDetails = response.data;
        headers['x-access-token'] = userDetails.token;
        const userRoles = await axios.get(`${process.env.REACT_APP_ROLES_API}/user-roles/${userDetails.id}`, Object.keys(headers).length > 0 && { headers });
        const information = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${userDetails.id}`, Object.keys(headers).length > 0 && { headers });

        userDetails.roles = userRoles.data;
        userDetails.information = information.data;

        return userDetails;
    } catch (error) {
        throw error;
    }
};

const verifyToken = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_SSO_AUTHENTICATION_API}/verify`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const csrfToken = async (headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_SSO_AUTHENTICATION_API}/csrf-token`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

export const SSOService = {
    login,
    refreshToken,
    verifyToken,
    csrfToken
};
