import axios from 'axios';

const get = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getAll = async (query, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users`, Object.keys(headers).length > 0 && { headers, params: query });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const create = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const update = async (id, data, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const findById = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const authentication = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/authentication`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const remove = async (id, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

const recoverPassword = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/recover-password`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const verifyToken = async (token, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/verify-token/${token}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const changePassword = async (id, data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}/change-password`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const changeEmail = async (id, data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}/change-email`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const resetPassword = async (hash, data) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/reset-password`, data, { params: hash });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const signUp = async (id, hash, data) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_USERS_MANAGEMENT_API}/users/${id}/sign-up`, data, { params: hash });

        return response.data;
    } catch (error) {
        throw error;
    }
};

export const UserManagementService = {
    get,
    getAll,
    create,
    update,
    findById,
    remove,
    authentication,
    recoverPassword,
    verifyToken,
    changePassword,
    changeEmail,
    resetPassword,
    signUp
};
