# Core React Library

Core React library.

### Version: 1.0.20

### Installing Library

Then via terminal:

```
npm install core-react-library

yarn add core-react-library

```

### Services used

List of services included in the library:


```
User Management Service
SSO Authentication Service
Email Service
Roles Service

```
Imports:

```
UserManagementService
SSOService
EmailService
RolesService

```

### Functions that are provided by Core React Library:

### - Messaging Service

```
import { EmailService } from 'core-react-library';

```

```
sendEmail(emailObject) - send email to Messaging Service and save it to your current collection of messages log.
```

Email Object :

```
{
    from: string,
    to: string,
    subject: string,
    body: string
}
```

Where:

```
from - from email address
to - to email address
subject - email subject
body - email body/message
attachments - email attachments
```
### - User Management Service

```
import { UserManagementService } from 'core-react-library';

```

```
create - Create new users.
findById - Get user by primary key.
getAll - Returns all users.
update - Update user by id.
remove - Delete user by primary key.
authentication - Authenticate user.
invitations - Send invitations to new clients.
recoverPassword - Recover password by id.
verifyToken - Verify token.
changePassword - Change password by id.

```

The object necessary for user creation:

```
{
    first_name: string,
    last_name: string,
    username: string,
    email: string,
    password: string
}
```

```
create - Create new invitation.
get - Get invitation by token.

```


### - SSO Authentication Service

```
import { SSOService } from 'core-react-library';

```

```
login - Authenticate user.
refreshToken - Refresh authentication jwt token.
csrfToken - CSRF token.
verifyToken - Verify token.
remove - Delete user by id.

```

The object necessary for authenticate :

```
{
    email: string,
    password: string
}
```

### - Role Service

```
import { RoleService } from 'core-react-library';


create - Create new role.
getAll - Returns all roles.
update - Update role by id.
remove - Delete role by id.
createRoleAction - Create actions for role .
getRoleActions - Get role actions.

```

```
import { RoleAction } from 'core-react-library';


update - Update role's action by id.
remove - Delete role's action by id.

```

```
import { UserRole } from 'core-react-library';


getUserRoles - Get user's role.
addUserRole - Add role for user.
removeUserRole - Delete user's role by id.

```


### Keys that need to be added and completed in ENV:

```
REACT_APP_USERS_MANAGEMENT_API:  /* Users management service URL *\
REACT_APP_SSO_AUTHENTICATION_API: /* SSO service URL *\
REACT_APP_EMAIL_SERVICE_API: /* Email service URL *\
REACT_APP_ROLES_API: /* Role service URL *\
REACT_APP_FILES_API: /* File service URL *\

```
